==> in_app_purchases_paywall_ui-0.1.1.tar.gz: lib/paywall/simple/subscription_row.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:in_app_purchases_interface/in_app_purchases_interface.dart';
import 'package:in_app_purchases_paywall_ui/paywall/simple/subscription_price_box.dart';

class SubscriptionRow extends StatelessWidget {
  final List<SubscriptionData> subscriptionListData;
  final Function(SubscriptionData) onPurchase;
  final ThemeData theme;
  final bool isSubscriptionLoading;

  bool _shouldBreakText = false;
  double _padding = 16;
  int _boxMarginX = 4;
  bool _expandItems = true;

  SubscriptionRow(this.subscriptionListData, this.onPurchase, this.isSubscriptionLoading, this.theme) {
    if (subscriptionListData.length == 1) {
      _expandItems = false;
    }
    if (subscriptionListData.length >= 3) {
      _shouldBreakText = true;
      _boxMarginX = 1;
    }
    if (subscriptionListData.length >= 4) {
      _padding = 0;
    }
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> subscriptionList = subscriptionListData
        .map((subscriptionData) =>
            SubscriptionPriceBox(subscriptionData, onPurchase, theme, _shouldBreakText, mx: _boxMarginX, expandItems: _expandItems))
        .toList(growable: false);
    if (isSubscriptionLoading) {
      return Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [Container(child: CircularProgressIndicator())],
      );
    }

    return Padding(
      padding: EdgeInsets.only(left: _padding, right: _padding),
      child: Row(mainAxisAlignment: MainAxisAlignment.center, children: subscriptionList),
    );
  }
}

==> in_app_purchases_paywall_ui-0.2.0.tar.gz: lib/paywall/simple/subscription_row.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:in_app_purchases_interface/in_app_purchases_interface.dart';
import 'package:in_app_purchases_paywall_ui/paywall/simple/subscription_price_box.dart';

/// Simple Subscription Row.
class SubscriptionRow extends StatelessWidget {
  final List<SubscriptionData> subscriptionListData;
  final Function(SubscriptionData) onPurchase;
  final ThemeData theme;
  final bool isSubscriptionLoading;

  bool _shouldBreakText = false;
  double _padding = 16;
  int _boxMarginX = 4;
  bool _expandItems = true;

  SubscriptionRow(this.subscriptionListData, this.onPurchase,
      this.isSubscriptionLoading, this.theme) {
    if (subscriptionListData.length == 1) {
      _expandItems = false;
    }
    if (subscriptionListData.length >= 3) {
      _shouldBreakText = true;
      _boxMarginX = 1;
    }
    if (subscriptionListData.length >= 4) {
      _padding = 0;
    }
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> subscriptionList = subscriptionListData
        .map((subscriptionData) => SubscriptionPriceBox(
            subscriptionData, onPurchase, theme, _shouldBreakText,
            mx: _boxMarginX, expandItems: _expandItems))
        .toList(growable: false);
    if (isSubscriptionLoading) {
      return Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [Container(child: CircularProgressIndicator())],
      );
    }

    return Padding(
      padding: EdgeInsets.only(left: _padding, right: _padding),
      child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: subscriptionList),
    );
  }
}
